wsireg.writers package
======================

Submodules
----------

wsireg.writers.ome\_tiff\_writer module
---------------------------------------

.. automodule:: wsireg.writers.ome_tiff_writer
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.writers.tiled\_ome\_tiff\_writer module
----------------------------------------------

.. automodule:: wsireg.writers.tiled_ome_tiff_writer
   :members:
   :undoc-members:
   :show-inheritance:

wsireg.writers.merge\_ome\_tiff\_writer module
----------------------------------------------

.. automodule:: wsireg.writers.merge_ome_tiff_writer
   :members:
   :undoc-members:
   :show-inheritance: